<?php namespace alfredoramos\meyouweus\event;

/**
 * @package Me You We Us - phpBB Extension
 * @author Alfredo Ramos <alfredo.ramos@yandex.com>
 * @copyright (c) 2015 Alfredo Ramos
 * @license GNU GPL 2.0 <https://www.gnu.org/licenses/gpl-2.0.txt>
 */

/**
 * @ignore
 */
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface {
	
	/* @var \phpbb\user */
	protected $user;
	
	/* @var \phpbb\config\config */
	protected $config;
	
	/**
	 * Constructor
	 *
	 * @param \phpbb\user				$user		User object
	 * @param \phpbb\config\config		$config		Config object
	 */
	public function __construct(\phpbb\user $user, \phpbb\config\config $config) {
		$this->user = $user;
		$this->config = $config;
	}
	
	static public function getSubscribedEvents() {
		return [
			'core.viewtopic_post_rowset_data'	=> 'me_you_we_us_replacement',
		];
	}
	
	public function me_you_we_us_replacement($event) {
		// Current user
		$user = [
			'user_id'		=> $event['row']['user_id'],
			'username'		=> $event['row']['username'],
			'user_colour'	=> $event['row']['user_colour']
		];
		
		// Posts data
		$posts = $event['rowset_data'];
		
		foreach($posts as $key => $value) {
			$posts['post_text'] = str_replace(
				array_keys($this->search_replace_array($user)),
				array_values($this->search_replace_array($user)),
				$posts['post_text']
			);
		}
		
		$event['rowset_data'] = array_replace_recursive($event['rowset_data'], $posts);
	}
	
	private function get_user_link($user = [], $board = false) {
		if (!is_array($user)) {
			return;
		}
		
		$data = [
			'link'	=> '<a href="%1$s" class="username%3$s"%4$s>%2$s</a>',
			'url'	=> './memberlist.php?mode=viewprofile&u=%1$d'
		];
		
		$link = vsprintf($data['link'], [
			sprintf($data['url'], $user['user_id']),
			$user['username'],
			(!empty($user['user_colour']) ? '-coloured' : ''),
			(!empty($user['user_colour']) ? sprintf(
				' style="color: #%1$s"',
				$user['user_colour']
			) : '')
		]);
		
		// Is a board URL "[us]"
		if ($board) {
			$link = vsprintf($data['link'], [
				generate_board_url(),
				$this->config['sitename'],
				'',
				''
			]);
		}
		
		return $link;
		
	}
	
	private function search_replace_array($user = []) {
		return [
			'[me]'	=> $this->get_user_link($this->user->data),
			'[you]'	=> $this->get_user_link($user),
			'[we]'	=> vsprintf('%1$s %2$s %3$s', [
				$this->get_user_link($this->user->data),
				strtolower($this->user->lang('AND')),
				$this->get_user_link($user)
			]),
			'[us]'	=> $this->get_user_link([], true)
		];
	}
}